pub struct AuthenticatedEncryptionDecrypt { /* private fields */ }Expand description
Decrypt structure to store the informations for the method GetPlaintextSymmetric
Implementations
Sourceimpl AuthenticatedEncryptionDecrypt
impl AuthenticatedEncryptionDecrypt
Sourcepub fn new(
encryption_key: &ByteArray,
nonce: &ByteArray,
associated_data: &[String],
) -> Result<Self, SymAuthenticatedEncryptionError>
pub fn new( encryption_key: &ByteArray, nonce: &ByteArray, associated_data: &[String], ) -> Result<Self, SymAuthenticatedEncryptionError>
New decrypt structure
Data according the the specifications of Swiss Post (GetPlaintextSymmetric)
Sourcepub fn get_plaintext_symmetric(
&mut self,
ciphertext: &ByteArray,
) -> Result<ByteArray, SymAuthenticatedEncryptionError>
pub fn get_plaintext_symmetric( &mut self, ciphertext: &ByteArray, ) -> Result<ByteArray, SymAuthenticatedEncryptionError>
Algorithm 6.2